.. seed-services-client documentation master file, created by
   sphinx-quickstart on Thu Oct 22 09:07:50 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to seed-services-client's documentation!
=========================================================

Contents:

.. toctree::
   :maxdepth: 2

   release-notes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

